@@ -41,9 +41,9 @@ const int    TODAY_MARGIN_WIDTH(2);
 
 struct TextColours
 {
-    QColor disabled;
     QColor thisMonth;
     QColor otherMonth;
+    QColor disabled;
     QColor thisMonthHoliday {HOLIDAY_BACKGROUND_COLOUR};
     QColor otherMonthHoliday;
 
@@ -239,22 +239,22 @@ void DayMatrix::updateEvents(const Resource& resource, const KADateTime& before,
     mResourceEventDates[id].clear();
     const QList<KAEvent> events = resource.events();
     const CalEvent::Types types = resource.enabledTypes() & CalEvent::ACTIVE;
-    for (const KAEvent& event : events)
+    for (const KAEvent& evnt : events)
     {
-        if (event.enabled()  &&  (event.category() & types))
+        if (evnt.enabled()  &&  (evnt.category() & types))
         {
             // The event has an enabled alarm type.
             // Find all its recurrences/repetitions within the time period.
             DateTime nextDt;
             for (KADateTime from = before;  ;  )
             {
-                event.nextOccurrence(from, nextDt, KAEvent::Repeats::Return);
+                evnt.nextOccurrence(from, nextDt, KAEvent::Repeats::Return);
                 if (!nextDt.isValid())
                     break;
                 from = nextDt.effectiveKDateTime().toTimeSpec(timeSpec);
                 if (from > to)
                     break;
-                if (!event.excludedByWorkTimeOrHoliday(from))
+                if (!evnt.excludedByWorkTimeOrHoliday(from))
                 {
                     mResourceEventDates[id] += from.date();
                     if (mResourceEventDates[id].count() >= NUMDAYS)
@@ -652,11 +652,11 @@ QColor DayMatrix::textColour(const TextColours& textColours, const QPalette& pal
 /*===========================================================================*/
 
 TextColours::TextColours(const QPalette& palette)
+    : thisMonth(palette.color(QPalette::Text))
+    , otherMonth(getShadedColour(thisMonth, true))
+    , disabled(getShadedColour(thisMonth, false))
 {
-    thisMonth         = palette.color(QPalette::Text);
-    disabled          = getShadedColour(thisMonth, false);
-    otherMonth        = getShadedColour(thisMonth, true);
-    thisMonthHoliday  = thisMonth;
+    thisMonthHoliday = thisMonth;
     thisMonthHoliday.setRed((thisMonthHoliday.red() + 255) / 2);
     otherMonthHoliday = getShadedColour(thisMonthHoliday, true);
 }
