@@ -33,12 +33,12 @@ ResourceId EventId::resourceDisplayId() const
 
 QString EventId::extractIDs(const QString& resourceEventId, QString& eventId)
 {
-    QRegularExpression rx(QStringLiteral("^(\\w+):(.*)$"));
+    static const QRegularExpression rx(QStringLiteral("^(\\w+):(.*)$"));
     QRegularExpressionMatch rxmatch = rx.match(resourceEventId);
     if (!rxmatch.hasMatch())
     {
         eventId = resourceEventId;   // no resource ID supplied
-        return QString();
+        return {};
     }
 
     // A resource ID has been supplied
