@@ -66,6 +66,7 @@ using namespace KCalendarCore;
 #include <QStandardPaths>
 #include <QPushButton>
 #include <QTemporaryFile>
+using namespace Qt::Literals::StringLiterals;
 
 //clazy:excludeall=non-pod-global-static
 
@@ -115,18 +116,18 @@ struct UpdateStatusData
     }
 };
 
-const QLatin1String KORG_DBUS_SERVICE("org.kde.korganizer");
-const QLatin1String KORG_DBUS_IFACE("org.kde.korganizer.Korganizer");
+const QLatin1StringView KORG_DBUS_SERVICE("org.kde.korganizer");
+const QLatin1StringView KORG_DBUS_IFACE("org.kde.korganizer.Korganizer");
 // D-Bus object path of KOrganizer's notification interface
 #define       KORG_DBUS_PATH            "/Korganizer"
 #define       KORG_DBUS_LOAD_PATH       "/korganizer_PimApplication"
-const QLatin1String KORG_MIME_TYPE("application/x-vnd.akonadi.calendar.event");
-const QLatin1String KORGANIZER_UID("korg-");
+const QLatin1StringView KORG_MIME_TYPE("application/x-vnd.akonadi.calendar.event");
+const QLatin1StringView KORGANIZER_UID("korg-");
 
-const QLatin1String ALARM_OPTS_FILE("alarmopts");
-const QLatin1String DONT_SHOW_ERRORS_GROUP("DontShowErrors");
+const QLatin1StringView ALARM_OPTS_FILE("alarmopts");
+const QLatin1StringView DONT_SHOW_ERRORS_GROUP("DontShowErrors");
 
-const QLatin1String GENERAL_GROUP("General");
+const QLatin1StringView GENERAL_GROUP("General");
 
 KAlarm::UpdateResult updateEvent(KAEvent&, KAlarm::UpdateError, QWidget* msgParent, bool saveIfReadOnly);
 void editNewTemplate(EditAlarmDlg::Type, const KAEvent& preset, QWidget* parent);
@@ -865,7 +866,7 @@ QList<KAEvent> getSortedActiveEvents(QObject* parent, AlarmListModel** model)
 * Reply = true if all alarms in the calendar were successfully imported
 *       = false if any alarms failed to be imported.
 */
-bool importAlarms(Resource& resource, QWidget* parent)
+bool importAlarms(Resource& resource, QWidget* parent)    //cppcheck-suppress[constParameterReference]  alarms are being added to 'resource'
 {
     qCDebug(KALARM_LOG) << "KAlarm::importAlarms" << resource.displayId();
     // Use KFileCustomDialog to allow files' mime types to be determined by
@@ -1682,7 +1683,7 @@ QStringList dontShowErrors(const EventId& eventId)
 {
     if (eventId.isEmpty())
         return {};
-    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
+    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + '/'_L1 + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     return group.readEntry(id, QStringList());
@@ -1708,7 +1709,7 @@ void setDontShowErrors(const EventId& eventId, const QStringList& tags)
 {
     if (eventId.isEmpty())
         return;
-    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
+    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + '/'_L1 + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     if (tags.isEmpty())
@@ -1726,7 +1727,7 @@ void setDontShowErrors(const EventId& eventId, const QString& tag)
 {
     if (eventId.isEmpty()  ||  tag.isEmpty())
         return;
-    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
+    KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + '/'_L1 + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
     QStringList tags = group.readEntry(id, QStringList());
@@ -1768,6 +1769,7 @@ bool convertTimeString(const QByteArray& timeString, KADateTime& dateTime, const
     else
     {
         noTime = false;
+        // Get the minute value
         *s++ = 0;
         dt[4] = strtoul(s, &end, 10);
         if (end == s  ||  *end  ||  dt[4] >= 60)
@@ -1836,8 +1838,8 @@ bool convertTimeString(const QByteArray& timeString, KADateTime& dateTime, const
             {
                 dt[0] = defaultDt.date().year();
                 date.setDate(dt[0],
-                            (dt[1] < 0 ? defaultDt.date().month() : dt[1]),
-                            (dt[2] < 0 ? defaultDt.date().day() : dt[2]));
+                            (dt[1] < 0 ? defaultDt.date().month() : dt[1]),    //cppcheck-suppress[invalidFunctionArg] dt[1] was tested for non zero
+                            (dt[2] < 0 ? defaultDt.date().day() : dt[2]));     //cppcheck-suppress[invalidFunctionArg] dt[2] was tested for non zero
             }
             else
                 date.setDate(2000, 1, 1);  // temporary substitute for date
@@ -1852,8 +1854,8 @@ bool convertTimeString(const QByteArray& timeString, KADateTime& dateTime, const
             const KADateTime now = KADateTime::currentDateTime(dateTime.timeSpec());
             date = dateTime.date();
             date.setDate(now.date().year(),
-                        (dt[1] < 0 ? now.date().month() : dt[1]),
-                        (dt[2] < 0 ? now.date().day() : dt[2]));
+                        (dt[1] < 0 ? now.date().month() : dt[1]),    //cppcheck-suppress[invalidFunctionArg] dt[1] was tested for non zero
+                        (dt[2] < 0 ? now.date().day() : dt[2]));     //cppcheck-suppress[invalidFunctionArg] dt[2] was tested for non zero
             if (!date.isValid())
                 return false;
             if (noDate  &&  time < now.time())
@@ -1907,7 +1909,7 @@ KADateTime applyTimeZone(const QString& tzstring, const QDate& date, const QTime
     const QString zone = tzstring.trimmed();
     if (!zone.isEmpty())
     {
-        if (zone == QLatin1String("UTC"))
+        if (zone == "UTC"_L1)
             spec = KADateTime::UTC;
         else
         {
@@ -1980,9 +1982,9 @@ namespace
 */
 void displayUpdateError(QWidget* parent, KAlarm::UpdateError code, const UpdateStatusData& status, bool showKOrgError)
 {
-    QString errmsg;
     if (status.status.status > KAlarm::UPDATE_KORG_ERR)
     {
+        QString errmsg;
         switch (code)
         {
             case KAlarm::ERR_ADD:
