@@ -1,7 +1,7 @@
 /*
  *  latecancel.cpp  -  widget to specify cancellation if late
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2004-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2004-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -63,14 +63,18 @@ LateCancelSelector::LateCancelSelector(bool allowHourMinute, QWidget* parent)
     connect(mTimeSelector, &TimeSelector::valueChanged, this, &LateCancelSelector::changed);
     hlayout->addWidget(mTimeSelector, 0, Qt::AlignLeft);
 
-    hlayout = new QHBoxLayout();
-    hlayout->setContentsMargins(CheckBox::textIndent(mCheckbox), 0, 0, 0);
-    topLayout->addLayout(hlayout);
+    mAutoCloseLayout = new QHBoxLayout();
+    const int indent = CheckBox::textIndent(mCheckbox);
+    if (layoutDirection() == Qt::LeftToRight)
+        mAutoCloseLayout->setContentsMargins(indent, 0, 0, 0);
+    else
+        mAutoCloseLayout->setContentsMargins(0, 0, indent, 0);
+    topLayout->addLayout(mAutoCloseLayout);
     mAutoClose = new CheckBox(i18n_chk_AutoCloseWin(), this);
     connect(mAutoClose, &CheckBox::toggled, this, &LateCancelSelector::changed);
     mAutoClose->setWhatsThis(i18nc("@info:whatsthis", "Automatically close the alarm window after the expiry of the late-cancellation period"));
-    hlayout->addWidget(mAutoClose);
-    hlayout->addStretch();
+    mAutoCloseLayout->addWidget(mAutoClose);
+    mAutoCloseLayout->addStretch();
 
     mAutoClose->hide();
     mAutoClose->setEnabled(false);
@@ -90,6 +94,14 @@ void LateCancelSelector::setReadOnly(bool ro)
     }
 }
 
+/******************************************************************************
+* Add a widget to the layout, right adjusted, beside Auto-close checkbox.
+*/
+void LateCancelSelector::addWidget(QWidget* widget)
+{
+    mAutoCloseLayout->addWidget(widget);
+}
+
 int LateCancelSelector::minutes() const
 {
     return mTimeSelector->period().asSeconds() / 60;
@@ -153,4 +165,6 @@ void LateCancelSelector::slotToggled(bool on)
     mAutoClose->setEnabled(on);
 }
 
+#include "moc_latecancel.cpp"
+
 // vim: et sw=4:
