@@ -25,11 +25,7 @@ public:
     explicit MainWindowBase(QWidget* parent = nullptr, Qt::WindowFlags f = Qt::Window);
 
 protected:
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void enterEvent(QEnterEvent*) override;
-#else
-    void enterEvent(QEvent*) override;
-#endif
 };
 
 // vim: et sw=4:
