@@ -1,14 +1,14 @@
 /*
  *  singlefileresourceconfigdialog.h - configuration dialog for single file resources.
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2020-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KACalendar>
+#include "kalarmcalendar/kacalendar.h"
 
 #include <QDialog>
 #include <QUrl>
@@ -73,5 +73,4 @@ private:
     bool          mCheckingDir {false};
 };
 
-
 // vim: et sw=4:
